<!DOCTYPE html>
<html>
	<head>
		<title>Anhelper:{{ self.id }}</title>
	</head>
<body>

	<h1>屏幕镜像:{{ device_id }}</h1>

	<p>Demo</p>

	<img src="{{ url_for('video_feed') }}" width='80%'>

</body>
</html> 

