.button-success,
.button-error,
.button-warning,
.button-secondary {
    color: white;
    border-radius: 4px;
    text-shadow: 0 1px 1px rgba(0, 0, 0, 0.2);
}

.button-success {
    background: rgb(28, 184, 65);
    /* this is a green */
}

.button-error {
    background: rgb(202, 60, 60);
    /* this is a maroon */
}

.button-warning {
    background: rgb(223, 117, 20);
    /* this is an orange */
}

.button-secondary {
    background: rgb(66, 184, 221);
    /* this is a light blue */
}

.align-center-container{
    display: flex;
    align-items: center;
}
.align-right-container{
    justify-content: right;
    text-align: right;
}

.icon-container{
    width: 3em;
}

.window-size{
    max-width: 960px;
    max-height: 960px;
}

.vertical-center{
    margin: 0 auto;
}

.align-bottom{
    position: absolute;
    bottom: 15px;
    margin-top: auto;
}

.vertical-container{
    position: relative;
}
.block{
    display: block;
}

.vdisplay{
    margin: 0 auto;
    max-height: 880px;
    cursor: pointer;
    object-fit: contain;
}